@@ -1,4 +1,6 @@
-# $Id: zoomtst1.pl,v 1.4 2006/11/02 17:48:26 mike Exp $
+#!/usr/bin/perl -w
+
+# $Id: zoomtst1.pl,v 1.6 2007/08/17 18:35:17 mike Exp $
 #
 # See ../README for a description of this program.
 # perl -I../../blib/lib -I../../blib/arch zoomtst1.pl <target> <query>
@@ -7,16 +9,23 @@ use strict;
 use warnings;
 use ZOOM;
 
-if (@ARGV != 2) {
-    print STDERR "Usage: $0 target query\n";
+if (@ARGV < 2 || @ARGV %2 == 1) {
+    print STDERR "Usage: $0 target query [<option> <value> ...]\n";
     print STDERR "	eg. $0 z3950.indexdata.dk/gils computer\n";
     exit 1;
 }
-my($host, $query) = @ARGV;
+my $host = shift(@ARGV);
+my $query = shift(@ARGV);
 
 eval {
     my $conn = new ZOOM::Connection($host, 0);
     $conn->option(preferredRecordSyntax => "usmarc");
+    while (@ARGV) {
+	my $key = shift(@ARGV);
+	my $value = shift(@ARGV);
+	$conn->option($key => $value);
+    }
+
     my $rs = $conn->search_pqf($query);
     my $n = $rs->size();
     print "Query '$query' found $n records\n";
